Coverage for /home/delusionalinsanity/bbrepos/matyan/src/matyan/config.py: 92%

# Coverage for /home/delusionalinsanity/bbrepos/matyan/src/matyan/config.py : 92%

## 12 statements 11 run 1 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 | import configparser import os from .helpers import project_dir __author__ = 'Artur Barseghyan' __copyright__ = '2019 Artur Barseghyan' __license__ = 'GPL-2.0-only OR LGPL-2.0-or-later' __all__ = ( 'CONFIG', 'CONFIG_INI_PATH', ) CONFIG = configparser.ConfigParser() CONFIG_INI_PATH = os.path.join(os.getcwd(), '.matyan.ini') if not os.path.exists(CONFIG_INI_PATH): CONFIG_INI_PATH = project_dir('.matyan.ini') CONFIG.read(CONFIG_INI_PATH)